@@ -169,7 +169,7 @@ void App::readSettings(void)
 {
     QSettings settings;
     queryBaseUrl = settings.value("QueryURL",
-                                  "http://mobile.viaggiatreno.it/viaggiatreno/mobile/stazione").toString();
+                                  "http://mobile.viaggiatreno.it/vt_pax_internet/mobile/stazione").toString();
     stationView->setBaseUrl(queryBaseUrl);
 
     recentStations = settings.value("RecentStations").toString().split(",");
